@@ -29,9 +29,9 @@
 
 #include <agrum/BN/inference/variableElimination.h>
 
-#include <agrum/BN/inference/BayesBall.h>
-#include <agrum/BN/inference/dSeparation.h>
-#include <agrum/graphs/binaryJoinTreeConverterDefault.h>
+#include <agrum/BN/algorithms/BayesBall.h>
+#include <agrum/BN/algorithms/dSeparation.h>
+#include <agrum/graphs/algorithms/binaryJoinTreeConverterDefault.h>
 #include <agrum/multidim/instantiation.h>
 #include <agrum/multidim/operators/multiDimCombineAndProjectDefault.h>
 #include <agrum/multidim/operators/multiDimProjection.h>
@@ -1041,12 +1041,16 @@ namespace gum {
       for ( const auto node : set ) {
         pot_list.insert( evidence[node] );
       }
-      MultiDimCombinationDefault<GUM_SCALAR, Potential> fast_combination(
+      if ( pot_list.size() == 1 ) {
+        return new Potential<GUM_SCALAR> ( **( pot_list.begin() ) );
+      }
+      else {
+        MultiDimCombinationDefault<GUM_SCALAR, Potential> fast_combination(
           __combination_op );
-      return fast_combination.combine( pot_list );
+        return fast_combination.combine( pot_list );
+      }
     }
 
-
     // if we still need to perform some inference task, do it
     __createNewJT( set );
     auto pot_list = __collectMessage( __targets2clique, __targets2clique );
