@@ -51,7 +51,7 @@
 namespace gum {
 
   /**
-   * @class sdyna sdyna.h <agrum/FMDP/SDyna/sdyna.h>
+   * @class SDYNA sdyna.h <agrum/FMDP/SDyna/sdyna.h>
    * @brief
    * @ingroup fmdp_group
    *
@@ -59,7 +59,6 @@ namespace gum {
    * Instance of SDyna architecture should inherit
    *
    */
-
   class SDYNA {
 
     // ###################################################################
@@ -73,20 +72,16 @@ namespace gum {
     static SDYNA* spitiInstance( double attributeSelectionThreshold = 0.99,
                                  double discountFactor = 0.9,
                                  double epsilon = 1,
-                                 Idx observationPhaseLenght = 100,
-                                 Idx nbValueIterationStep = 10 ) {
-      bool actionReward = false;
+                                 Idx    observationPhaseLenght = 100,
+                                 Idx    nbValueIterationStep = 10 ) {
+      bool               actionReward = false;
       ILearningStrategy* ls = new FMDPLearner<CHI2TEST, CHI2TEST, ITILEARNER>(
           attributeSelectionThreshold, actionReward );
       IPlanningStrategy<double>* ps =
           StructuredPlaner<double>::sviInstance( discountFactor, epsilon );
       IDecisionStrategy* ds = new E_GreedyDecider();
-      return new SDYNA( ls,
-                        ps,
-                        ds,
-                        observationPhaseLenght,
-                        nbValueIterationStep,
-                        actionReward );
+      return new SDYNA(
+          ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward );
     }
 
     // ==========================================================================
@@ -96,9 +91,9 @@ namespace gum {
                                    double similarityThreshold = 0.3,
                                    double discountFactor = 0.9,
                                    double epsilon = 1,
-                                   Idx observationPhaseLenght = 100,
-                                   Idx nbValueIterationStep = 10 ) {
-      bool actionReward = false;
+                                   Idx    observationPhaseLenght = 100,
+                                   Idx    nbValueIterationStep = 10 ) {
+      bool               actionReward = false;
       ILearningStrategy* ls = new FMDPLearner<GTEST, GTEST, IMDDILEARNER>(
           attributeSelectionThreshold, actionReward, similarityThreshold );
       IPlanningStrategy<double>* ps = StructuredPlaner<double>::spumddInstance(
@@ -120,21 +115,17 @@ namespace gum {
                                    double similarityThreshold = 0.3,
                                    double discountFactor = 0.9,
                                    double epsilon = 1,
-                                   Idx observationPhaseLenght = 100,
-                                   Idx nbValueIterationStep = 10 ) {
-      bool actionReward = true;
+                                   Idx    observationPhaseLenght = 100,
+                                   Idx    nbValueIterationStep = 10 ) {
+      bool               actionReward = true;
       ILearningStrategy* ls = new FMDPLearner<GTEST, GTEST, IMDDILEARNER>(
           attributeSelectionThreshold, actionReward, similarityThreshold );
       AdaptiveRMaxPlaner* rm = AdaptiveRMaxPlaner::ReducedAndOrderedInstance(
           ls, discountFactor, epsilon );
       IPlanningStrategy<double>* ps = rm;
-      IDecisionStrategy* ds = rm;
-      return new SDYNA( ls,
-                        ps,
-                        ds,
-                        observationPhaseLenght,
-                        nbValueIterationStep,
-                        actionReward );
+      IDecisionStrategy*         ds = rm;
+      return new SDYNA(
+          ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward );
     }
 
     // ==========================================================================
@@ -143,21 +134,17 @@ namespace gum {
     static SDYNA* RMaxTreeInstance( double attributeSelectionThreshold = 0.99,
                                     double discountFactor = 0.9,
                                     double epsilon = 1,
-                                    Idx observationPhaseLenght = 100,
-                                    Idx nbValueIterationStep = 10 ) {
-      bool actionReward = true;
+                                    Idx    observationPhaseLenght = 100,
+                                    Idx    nbValueIterationStep = 10 ) {
+      bool               actionReward = true;
       ILearningStrategy* ls = new FMDPLearner<GTEST, GTEST, ITILEARNER>(
           attributeSelectionThreshold, actionReward );
       AdaptiveRMaxPlaner* rm =
           AdaptiveRMaxPlaner::TreeInstance( ls, discountFactor, epsilon );
       IPlanningStrategy<double>* ps = rm;
-      IDecisionStrategy* ds = rm;
-      return new SDYNA( ls,
-                        ps,
-                        ds,
-                        observationPhaseLenght,
-                        nbValueIterationStep,
-                        actionReward );
+      IDecisionStrategy*         ds = rm;
+      return new SDYNA(
+          ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward );
     }
 
     // ==========================================================================
@@ -167,20 +154,16 @@ namespace gum {
                                      double similarityThreshold = 0.3,
                                      double discountFactor = 0.9,
                                      double epsilon = 1,
-                                     Idx observationPhaseLenght = 100,
-                                     Idx nbValueIterationStep = 10 ) {
-      bool actionReward = true;
+                                     Idx    observationPhaseLenght = 100,
+                                     Idx    nbValueIterationStep = 10 ) {
+      bool               actionReward = true;
       ILearningStrategy* ls = new FMDPLearner<GTEST, GTEST, IMDDILEARNER>(
           attributeSelectionThreshold, actionReward, similarityThreshold );
       IPlanningStrategy<double>* ps =
           StructuredPlaner<double>::spumddInstance( discountFactor, epsilon );
       IDecisionStrategy* ds = new RandomDecider();
-      return new SDYNA( ls,
-                        ps,
-                        ds,
-                        observationPhaseLenght,
-                        nbValueIterationStep,
-                        actionReward );
+      return new SDYNA(
+          ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward );
     }
 
     // ==========================================================================
@@ -189,20 +172,16 @@ namespace gum {
     static SDYNA* RandomTreeInstance( double attributeSelectionThreshold = 0.99,
                                       double discountFactor = 0.9,
                                       double epsilon = 1,
-                                      Idx observationPhaseLenght = 100,
-                                      Idx nbValueIterationStep = 10 ) {
-      bool actionReward = true;
+                                      Idx    observationPhaseLenght = 100,
+                                      Idx    nbValueIterationStep = 10 ) {
+      bool               actionReward = true;
       ILearningStrategy* ls = new FMDPLearner<CHI2TEST, CHI2TEST, ITILEARNER>(
           attributeSelectionThreshold, actionReward );
       IPlanningStrategy<double>* ps =
           StructuredPlaner<double>::sviInstance( discountFactor, epsilon );
       IDecisionStrategy* ds = new RandomDecider();
-      return new SDYNA( ls,
-                        ps,
-                        ds,
-                        observationPhaseLenght,
-                        nbValueIterationStep,
-                        actionReward );
+      return new SDYNA(
+          ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward );
     }
 
 
@@ -221,13 +200,13 @@ namespace gum {
      */
     // ==========================================================================
     private:
-    SDYNA( ILearningStrategy* learner,
+    SDYNA( ILearningStrategy*         learner,
            IPlanningStrategy<double>* planer,
-           IDecisionStrategy* decider,
-           Idx observationPhaseLenght,
-           Idx nbValueIterationStep,
-           bool actionReward,
-           bool verbose = true );
+           IDecisionStrategy*         decider,
+           Idx                        observationPhaseLenght,
+           Idx                        nbValueIterationStep,
+           bool                       actionReward,
+           bool                       verbose = true );
 
     // ==========================================================================
     /// Destructor
@@ -265,9 +244,7 @@ namespace gum {
      * process
      */
     // ==========================================================================
-    void addVariable( const DiscreteVariable* var ) {
-      _fmdp->addVariable( var );
-    }
+    void addVariable( const DiscreteVariable* var ) { _fmdp->addVariable( var ); }
 
     /// @}
 
@@ -341,8 +318,8 @@ namespace gum {
     // ==========================================================================
     void feedback( const Instantiation& originalState,
                    const Instantiation& reachedState,
-                   Idx performedAction,
-                   double obtainedReward );
+                   Idx                  performedAction,
+                   double               obtainedReward );
 
     // ==========================================================================
     /**
@@ -380,9 +357,7 @@ namespace gum {
     // ==========================================================================
     std::string toString();
 
-    std::string optimalPolicy2String() {
-      return __planer->optimalPolicy2String();
-    }
+    std::string optimalPolicy2String() { return __planer->optimalPolicy2String(); }
 
 
     // ###################################################################
