@@ -43,7 +43,7 @@ namespace gum {
   // ===========================================================================
   // clang-format off
   /**
-   * @class MultiDimCIModel
+   * @class MultiDimICIModel
    * @headerfile multiDimICIModel.h <agrum/multidim/ICIModels/multiDimICIModel.h>
    * @ingroup multidim_group
    *
@@ -117,6 +117,18 @@ namespace gum {
       return i->toString();
     };
 
+    /**
+     * @brief Copy of a multiDimICIModel.
+     *
+     * This method is virtual because it should be optimized in certain
+     * MultiDimContainer.
+     *
+     * @throw OperationNotAllowed Raised if src does not have the same domain
+     * size than this MultiDimContainer.
+     **/
+    virtual void
+    copyFrom( const MultiDimContainer<GUM_SCALAR>& src ) const override;
+
     /**
      * @return the real number of parameters used for this table. This function
      * is used for compute @see compressionRatio()
@@ -155,7 +167,7 @@ namespace gum {
     /// @{
 
     /// \f$ P(e | c_i) \f$ in Henrion (89) in a hashtable with a default_value.
-    GUM_SCALAR __default_weight;
+    mutable GUM_SCALAR __default_weight;
 
     mutable HashTable<const DiscreteVariable*, GUM_SCALAR> __causal_weights;
     /// @}
@@ -170,6 +182,6 @@ namespace gum {
 
 } /* namespace gum */
 
-#include <agrum/multidim/ICIModels/multiDimICIModel.tcc>
+#include <agrum/multidim/ICIModels/multiDimICIModel_tpl.h>
 
 #endif /* GUM_MULTI_DIM_ICI_MODEL_H */
